package com.caimei365.order.mapper;

import com.caimei365.order.model.vo.OrderPayLinkVo;
import com.caimei365.order.model.vo.OrderVo;
import org.apache.ibatis.annotations.Mapper;

import java.math.BigDecimal;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/7/29
 */
@Mapper
public interface PayOrderMapper {
    /**
     * 获取线上支付全局开关状态
     */
    Integer getPayOnLineSwitch();
    /**
     * 根据订单Id获取订单
     * @param orderId 订单Id
     */
    OrderVo getOrderByOrderId(Integer orderId);
    /**
     * 查询审核中的退款退货数量
     * @param orderId 订单Id
     */
    int getRefundCount(Integer orderId);
    /**
     * 更新订单状态
     * @param order 主订单
     */
    void updateOrderStatus(OrderVo order);
    /**
     * 根据用户Id更新余额
     * @param userMoney      用户余额
     * @param availableMoney 用户可用余额
     * @param userId 用户Id
     */
    void updateMoneyByUserId(double userMoney, Double availableMoney, Integer userId);
    /**
     * 支付链接
     * @param orderId 订单Id
     * @param amount  本次待付款金额
     */
    OrderPayLinkVo getOrderPayLink(Integer orderId, Double amount);
    /**
     * 支付链接
     * @param linkLogo  链接标识
     */
    OrderPayLinkVo getPayLinkByLinkLogo(String linkLogo);
    /**
     * 新增支付链接
     */
    void insertOrderPayLink(OrderPayLinkVo orderPayLink);
    /**
     * 更新支付链接
     */
    void updateOrderPayLink(OrderPayLinkVo orderPayLink);
    /**
     * 修改支付链接状态
     */
    void updateOrderPayLinkStatus(OrderPayLinkVo orderPayLink);
    /**
     * 订单促销Id
     * @param orderId 订单Id
     */
    Integer getOrderPromotionsId(Integer orderId);



}
